From a10e6d00b138969df60b26284918bb63b988752a Mon Sep 17 00:00:00 2001
From: Brandon Bergren <bdragon@rtk0.net>
Date: Mon, 14 Feb 2011 17:44:13 +0000
Subject: [PATCH] Fix some $ in js files.

---
 js/gmap_shapes.js        | 12 ++++++------
 js/shapeloader_static.js |  4 ++--
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/js/shapeloader_static.js b/js/shapeloader_static.js
index 23284e3..ff6eaed 100644
--- a/js/shapeloader_static.js
+++ b/js/shapeloader_static.js
@@ -8,7 +8,7 @@
  * Commonly used with macros.
  */
 
-/*global $, Drupal */
+/*global jQuery, Drupal */
 
 // Add a gmap handler
 Drupal.gmap.addHandler('gmap', function (elem) {
@@ -21,7 +21,7 @@ Drupal.gmap.addHandler('gmap', function (elem) {
       // Store the shapes in s and reset obj.vars.shapes.
       var s = obj.vars.shapes;
       obj.vars.shapes = [];
-      $.each(s, function (i, shape) {
+      jQuery.each(s, function (i, shape) {
         if (!shape.opts) {
           shape.opts = {};
         }
diff --git a/js/gmap_shapes.js b/js/gmap_shapes.js
index 5665265..e4375d8 100644
--- a/js/gmap_shapes.js
+++ b/js/gmap_shapes.js
@@ -6,7 +6,7 @@
  * GMap API version / Base case
  */
 
 /*global $, Drupal, GEvent, GLatLng, GPolygon, GPolyline */
 
 Drupal.gmap.addHandler('gmap', function (elem) {
   var obj = this;
@@ -32,12 +32,12 @@ Drupal.gmap.addHandler('gmap', function (elem) {
       pa = obj.poly.calcPolyPoints(shape.center, radius, shape.numpoints);
     }
     else if (shape.type === 'polygon') {
-      $.each(shape.points, function (i, n) {
+      jQuery.each(shape.points, function (i, n) {
         pa.push(new GLatLng(n[0], n[1]));
       });
     }
     else if (shape.type === 'line') {
-      $.each(shape.points, function (i, n) {
+      jQuery.each(shape.points, function (i, n) {
         pa.push(new GLatLng(n[0], n[1]));
       });
       fillstyle = false;
@@ -75,7 +75,7 @@ Drupal.gmap.addHandler('gmap', function (elem) {
       shape.opacity = style[2];
     }
     else if (shape.type == 'encoded_polygon') {
-      $.each(shape.polylines, function(i, polyline) {
+      jQuery.each(shape.polylines, function(i, polyline) {
         polyline.color = style[0];
         polyline.weight = style[1];
         polyline.opacity = style[2];
@@ -86,7 +86,7 @@ Drupal.gmap.addHandler('gmap', function (elem) {
       shape.outline = true;
     }
 
-    $.each(style, function (i, n) {
+    jQuery.each(style, function (i, n) {
       cargs.push(n);
     });
     if (shape.opts) {
@@ -138,7 +138,7 @@ Drupal.gmap.addHandler('gmap', function (elem) {
 
   obj.bind('clearshapes', function () {
     if (obj.vars.shapes) {
-      $.each(obj.vars.shapes, function (i, n) {
+      jQuery.each(obj.vars.shapes, function (i, n) {
         obj.change('delshape', -1, n);
       });
     }
@@ -6,7 +6,7 @@
  */
 
-/*global $, Drupal, GEvent, GLatLng, GPolygon, GPolyline */
+/*global jQuery, Drupal, GEvent, GLatLng, GPolygon, GPolyline */
 
 Drupal.gmap.addHandler('gmap', function (elem) {
-- 
GitLab